@@ -886,8 +886,8 @@ class PerturbFlow(nn.Module):
         elif self.loss_func == 'poisson':
             rate = concentrate.exp()
             theta = dist.DirichletMultinomial(total_count=1, concentration=rate).mean
-            rate = theta * library_size
-            counts = dist.Poisson(rate=rate).to_event(1).mean
+            counts = theta * library_size
+            #counts = dist.Poisson(rate=rate).to_event(1).mean
         elif self.loss_func == 'multinomial':
             rate = concentrate.exp()
             theta = dist.DirichletMultinomial(total_count=1, concentration=rate).mean
@@ -927,7 +927,7 @@ class PerturbFlow(nn.Module):
         E = []
         with tqdm(total=len(dataloader), desc='', unit='batch') as pbar:
             for Z_batch, L_batch, _ in dataloader:
-                if self.loss_func != 'multinomial':
+                if self.loss_func not in ['multinomial','poisson']:
                     L_batch = None
                 concentrate = self._get_expression_response(Z_batch)
                 if use_sampler:
